@@ -5,16 +5,14 @@ use warnings;
 
 use base 'ObjectDB::Related';
 
-our $VERSION = '3.04';
+our $VERSION = '3.05';
 
 sub create_related {
     my $self = shift;
-    my ($row) = shift;
-
-    my @related = @_ == 1 ? ref $_[0] eq 'ARRAY' ? @{$_[0]} : ($_[0]) : ({@_});
+    my ($row, $related) = @_;
 
     my @row_objects;
-    foreach my $related (@related) {
+    foreach my $related (@$related) {
         my %params = %$related;
 
         my $meta = $self->meta;
@@ -43,7 +41,7 @@ sub create_related {
         push @row_objects, $row_object;
     }
 
-    return @related == 1 ? $row_objects[0] : @row_objects;
+    return @row_objects;
 }
 
 sub find_related {
@@ -61,10 +59,11 @@ sub find_related {
 
     my $table     = $meta->class->meta->table;
     my $map_table = $meta->map_class->meta->table;
-    $params{where} =
-      ["$map_table.$map_table_to" => $row->column($map_table_from)];
 
-    return $meta->class->table->find(%params);
+    my @where = @{$params{where} || []};
+    unshift @where, "$map_table.$map_table_to" => $row->column($map_table_from);
+
+    return $meta->class->table->find(%params, where => \@where);
 }
 
 sub count_related {
@@ -82,33 +81,32 @@ sub count_related {
 
     my $table     = $meta->class->meta->table;
     my $map_table = $meta->map_class->meta->table;
-    $params{where} =
-      ["$map_table.$map_table_to" => $row->column($map_table_from)];
 
-    return $meta->class->table->count(%params);
+    my @where = @{$params{where} || []};
+    unshift @where, "$map_table.$map_table_to" => $row->column($map_table_from);
+
+    return $meta->class->table->count(%params, where => \@where);
 }
 
 sub delete_related {
     my $self = shift;
     my ($row, %params) = @_;
 
-    $params{where} ||= [];
-
     my $meta = $self->meta;
 
     my $map_from = $meta->map_from;
     my $map_to   = $meta->map_to;
 
-    my ($to, $from) =
+    my ($map_table_to, $map_table_from) =
       %{$meta->map_class->meta->get_relationship($map_from)->map};
 
-    push @{$params{where}}, ($to => $row->get_column($from));
+    my $table     = $meta->class->meta->table;
+    my $map_table = $meta->map_class->meta->table;
 
-    if ($meta->where) {
-        push @{$params{where}}, %{$meta->where};
-    }
+    my @where = @{$params{where} || []};
+    unshift @where, "$map_table.$map_table_to" => $row->column($map_table_from);
 
-    return $meta->map_class->table->delete(%params);
+    return $meta->map_class->table->delete(%params, where => \@where);
 }
 
 1;
